package
Version:
v0.4.0
Opens a new window with list of versions in this module.
Published: Oct 16, 2019
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Node struct {
XMLName xml.Name
Content []byte `xml:",innerxml"`
Nodes []Node `xml:",any"`
}
Source Files
¶
- content.go
- pdf_content.go
- strings.go
- xml_content.go
Click to show internal directories.
Click to hide internal directories.